Index: src/compiler/interpreter-assembler.h |
diff --git a/src/compiler/interpreter-assembler.h b/src/compiler/interpreter-assembler.h |
index 11f43ccf2648bcc2d2d36f0764bae61eabc1dcae..e49f9e919d75f28a207a5e85c10114b4bf93bbdc 100644 |
--- a/src/compiler/interpreter-assembler.h |
+++ b/src/compiler/interpreter-assembler.h |
@@ -101,8 +101,17 @@ class InterpreterAssembler { |
// Load the TypeFeedbackVector for the current function. |
Node* LoadTypeFeedbackVector(); |
- // Call JSFunction or Callable |function| with |arg_count| (not including |
- // receiver) and the first argument located at |first_arg|. |
+ // Call constructor |constructor| with |arg_count| arguments (not |
+ // including receiver) and the first argument located at |
+ // |first_arg|. The |original_constructor| is the same as the |
+ // |constructor| for the new keyword, but differs for the super |
+ // keyword. |
+ Node* CallConstruct(Node* original_constructor, Node* constructor, |
+ Node* first_arg, Node* arg_count); |
+ |
+ // Call JSFunction or Callable |function| with |arg_count| |
+ // arguments (not including receiver) and the first argument |
+ // located at |first_arg|. |
Node* CallJS(Node* function, Node* first_arg, Node* arg_count); |
// Call an IC code stub. |